==> openjdk13-13.0.13_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_sw.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_sw extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "KES", "Ksh" },
            { "THB", "\u0e3f" },
            { "TZS", "TSh" },
            { "aed", "Dirham ya Falme za Kiarabu" },
            { "afn", "Afghani ya Afghanistan" },
            { "all", "Lek ya Albania" },
            { "amd", "Dram ya Armenia" },
            { "ang", "Guilder ya Antili za Kiholanzi" },
            { "aoa", "Kwanza ya Angola" },
            { "ars", "Peso ya Argentina" },
            { "aud", "Dola ya Australia" },
            { "awg", "Florin ya Aruba" },
            { "azn", "Manat ya Azerbaijan" },
            { "bam", "Convertible Mark ya Bosnia na Hezegovina" },
            { "bbd", "Dola ya Barbados" },
            { "bdt", "Taka ya Bangladesh" },
            { "bgn", "Lev ya Bulgaria" },
            { "bhd", "Dinar ya Bahrain" },
            { "bif", "Faranga ya Burundi" },
            { "bmd", "Dola ya Bermuda" },
            { "bnd", "Dola ya Brunei" },
            { "bob", "Boliviano ya Bolivia" },
            { "brl", "Real ya Brazil" },
            { "bsd", "Dola ya Bahamas" },
            { "btn", "Ngultrum ya Bhutan" },
            { "bwp", "Pula ya Botswana" },
            { "byn", "Ruble ya Belarus" },
            { "byr", "Ruble ya Belarusi (2000\u20132016)" },
            { "bzd", "Dola ya Belize" },
            { "cad", "Dola ya Canada" },
            { "cdf", "Faranga ya Kongo" },
            { "chf", "Faranga ya Uswisi" },
            { "clp", "Peso ya Chile" },
            { "cnh", "Yuan ya Uchina (huru)" },
            { "cny", "Yuan ya Uchina" },
            { "cop", "Peso ya Colombia" },
            { "crc", "Colon ya Costa Rica" },
            { "cuc", "Peso ya Cuba Inayoweza Kubadilishwa" },
            { "cup", "Peso ya Cuba" },
            { "cve", "Eskudo ya Cape Verde" },
            { "czk", "CZK" },
            { "djf", "Faranga ya Djibouti" },
            { "dkk", "Krone ya Denmark" },
            { "dop", "Peso ya Dominica" },
            { "dzd", "Dinar ya Aljeria" },
            { "egp", "Pauni ya Misri" },
            { "ern", "Nakfa ya Eritrea" },
            { "etb", "Birr ya Uhabeshi" },
            { "eur", "Yuro" },
            { "fjd", "Dola ya Fiji" },
            { "fkp", "Pauni ya Visiwa vya Falkland" },
            { "gbp", "Pauni ya Uingereza" },
            { "gel", "Lari ya Georgia" },
            { "ghc", "Sedi ya Ghana" },
            { "ghs", "Cedi ya Ghana" },
            { "gip", "Pauni ya Gibraltar" },
            { "gmd", "Dalasi ya Gambia" },
            { "gnf", "Faranga ya Guinea" },
            { "gns", "Faranga ya Gine" },
            { "gtq", "Quetzal ya Guatemala" },
            { "gyd", "Dola ya Guyana" },
            { "hkd", "Dola ya Hong Kong" },
            { "hnl", "Lempira ya Hondurasi" },
            { "hrk", "Kuna ya Croatia" },
            { "htg", "Gourde ya Haiti" },
            { "huf", "Forint ya Hungaria" },
            { "idr", "Rupiah ya Indonesia" },
            { "ils", "Shekeli Mpya ya Israel" },
            { "inr", "Rupia ya India" },
            { "iqd", "Dinar ya Iraq" },
            { "irr", "Rial ya Iran" },
            { "isk", "Krona ya Aisilandi" },
            { "jmd", "Dola ya Jamaica" },
            { "jod", "Dinar ya Jordan" },
            { "jpy", "Yen ya Ujapani" },
            { "kes", "Shilingi ya Kenya" },
            { "kgs", "Som ya Kyrgystan" },
            { "khr", "Riel ya Cambodia" },
            { "kmf", "Faranga ya Comoros" },
            { "kpw", "Won ya Korea Kaskazini" },
            { "krw", "Won ya Korea Kusini" },
            { "kwd", "Dinar ya Kuwait" },
            { "kyd", "Dola ya Visiwa vya Cayman" },
            { "kzt", "Tenge ya Kazakhstan" },
            { "lak", "Kip ya Laosi" },
            { "lbp", "Pauni ya Lebanon" },
            { "lkr", "Rupia ya Sri Lanka" },
            { "lrd", "Dola ya Liberia" },
            { "lsl", "Loti ya Lesoto" },
            { "ltl", "Litas ya Lithuania" },
            { "lvl", "Lats ya Lativia" },
            { "lyd", "Dinari ya Libya" },
            { "mad", "Dirham ya Morocco" },
            { "mdl", "Leu ya Moldova" },
            { "mga", "Ariari ya Madagascar" },
            { "mkd", "Denar ya Macedonia" },
            { "mmk", "Kyat ya Myanmar" },
            { "mnt", "Tugrik ya Mongolia" },
            { "mop", "Pataca ya Macau" },
            { "mro", "Ouguiya ya Mauritania (1973\u20132017)" },
            { "mru", "Ouguiya ya Mauritania" },
            { "mur", "Rupia ya Mauritius" },
            { "mvr", "Rufiyaa ya Maldives" },
            { "mwk", "Kwacha ya Malawi" },
            { "mxn", "Peso ya Mexico" },
            { "myr", "Ringgit ya Malaysia" },
            { "mzm", "Metikali ya Msumbiji (1980\u20132006)" },
            { "mzn", "Metikali ya Msumbiji" },
            { "nad", "Dola ya Namibia" },
            { "ngn", "Naira ya Nigeria" },
            { "nio", "Cordoba ya Nicaragua" },
            { "nok", "Krone ya Norway" },
            { "npr", "Rupia ya Nepal" },
            { "nzd", "Dola ya New Zealand" },
            { "omr", "Rial ya Omani" },
            { "pab", "Balboa ya Panama" },
            { "pen", "Sol ya Peru" },
            { "pgk", "Kina ya Papua New Guinea" },
            { "php", "Peso ya Ufilipino" },
            { "pkr", "Rupia ya Pakistan" },
            { "pln", "Zloty ya Poland" },
            { "pyg", "Guarani ya Paraguay" },
            { "qar", "Rial ya Qatar" },
            { "ron", "Leu ya Romania" },
            { "rsd", "Dinar ya Serbia" },
            { "rub", "Ruble ya Urusi" },
            { "rwf", "Faranga ya Rwanda" },
            { "sar", "Riyal ya Saudia" },
            { "sbd", "Dola ya Visiwa vya Solomon" },
            { "scr", "Rupia ya Ushelisheli" },
            { "sdg", "Pauni ya Sudan" },
            { "sdp", "Pauni ya Sudani (1957\u20131998)" },
            { "sek", "Krona ya Uswidi" },
            { "sgd", "Dola ya Singapore" },
            { "shp", "Pauni ya St. Helena" },
            { "sll", "Leone" },
            { "sos", "Shilingi ya Somalia" },
            { "srd", "Dola ya Suriname" },
            { "ssp", "Pauni ya Sudan Kusini" },
            { "std", "Dobra ya Sao Tome na Principe (1977\u20132017)" },
            { "stn", "Dobra ya Sao Tome na Principe" },
            { "syp", "Pauni ya Syria" },
            { "szl", "Lilangeni" },
            { "thb", "Baht ya Tailandi" },
            { "tjs", "Somoni ya Tajikistan" },
            { "tmt", "Manat ya Turkmenistan" },
            { "tnd", "Dinari ya Tunisia" },
            { "top", "Pa\u02bbanga ya Tonga" },
            { "try", "Lira ya Uturuki" },
            { "ttd", "Dola ya Trinidad na Tobago" },
            { "twd", "Dola ya Taiwan" },
            { "tzs", "Shilingi ya Tanzania" },
            { "uah", "Hryvnia ya Ukraine" },
            { "ugx", "Shilingi ya Uganda" },
            { "usd", "Dola ya Marekani" },
            { "uyu", "Peso ya Uruguay" },
            { "uzs", "Som ya Uzbekistan" },
            { "vef", "Bolivar ya Venezuela (2008\u20132018)" },
            { "ves", "Bolivar ya Venezuela" },
            { "vnd", "Dong ya Vietnam" },
            { "vuv", "Vatu ya Vanuatu" },
            { "wst", "Tala ya Samoa" },
            { "xaf", "Faranga ya Afrika ya Kati CFA" },
            { "xcd", "Dola ya Caribbean Mashariki" },
            { "xof", "Faranga ya Afrika Magharibi CFA" },
            { "xpf", "Faranga ya CFP" },
            { "xxx", "Sarafu isiyojulikana" },
            { "yer", "Rial ya Yemen" },
            { "zar", "Randi ya Afrika Kusini" },
            { "zmk", "Kwacha ya Zambia (1968\u20132012)" },
            { "zmw", "Kwacha ya Zambia" },
            { "zwd", "Dola ya Zimbabwe" },
        };
        return data;
    }
}

==> openjdk15-15.0.9_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_sw.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_sw extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "Ksh" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LTL", "LTL" },
            { "LVL", "LVL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TSh" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "aed", "Dirham ya Falme za Kiarabu" },
            { "afn", "Afghani ya Afghanistan" },
            { "all", "Lek ya Albania" },
            { "amd", "Dram ya Armenia" },
            { "ang", "Guilder ya Antili za Kiholanzi" },
            { "aoa", "Kwanza ya Angola" },
            { "ars", "Peso ya Argentina" },
            { "aud", "Dola ya Australia" },
            { "awg", "Florin ya Aruba" },
            { "azn", "Manat ya Azerbaijan" },
            { "bam", "Convertible Mark ya Bosnia na Hezegovina" },
            { "bbd", "Dola ya Barbados" },
            { "bdt", "Taka ya Bangladesh" },
            { "bgn", "Lev ya Bulgaria" },
            { "bhd", "Dinar ya Bahrain" },
            { "bif", "Faranga ya Burundi" },
            { "bmd", "Dola ya Bermuda" },
            { "bnd", "Dola ya Brunei" },
            { "bob", "Boliviano ya Bolivia" },
            { "brl", "Real ya Brazil" },
            { "bsd", "Dola ya Bahamas" },
            { "btn", "Ngultrum ya Bhutan" },
            { "bwp", "Pula ya Botswana" },
            { "byn", "Ruble ya Belarus" },
            { "byr", "Ruble ya Belarusi (2000\u20132016)" },
            { "bzd", "Dola ya Belize" },
            { "cad", "Dola ya Canada" },
            { "cdf", "Faranga ya Kongo" },
            { "chf", "Faranga ya Uswisi" },
            { "clp", "Peso ya Chile" },
            { "cnh", "Yuan ya Uchina (huru)" },
            { "cny", "Yuan ya Uchina" },
            { "cop", "Peso ya Colombia" },
            { "crc", "Colon ya Costa Rica" },
            { "cuc", "Peso ya Cuba Inayoweza Kubadilishwa" },
            { "cup", "Peso ya Cuba" },
            { "cve", "Eskudo ya Cape Verde" },
            { "czk", "koruna ya Jamhuri ya Czech" },
            { "djf", "Faranga ya Djibouti" },
            { "dkk", "Krone ya Denmark" },
            { "dop", "Peso ya Dominica" },
            { "dzd", "Dinar ya Aljeria" },
            { "egp", "Pauni ya Misri" },
            { "ern", "Nakfa ya Eritrea" },
            { "etb", "Birr ya Uhabeshi" },
            { "eur", "Yuro" },
            { "fjd", "Dola ya Fiji" },
            { "fkp", "Pauni ya Visiwa vya Falkland" },
            { "gbp", "Pauni ya Uingereza" },
            { "gel", "Lari ya Georgia" },
            { "ghc", "Sedi ya Ghana" },
            { "ghs", "Cedi ya Ghana" },
            { "gip", "Pauni ya Gibraltar" },
            { "gmd", "Dalasi ya Gambia" },
            { "gnf", "Faranga ya Guinea" },
            { "gns", "Faranga ya Gine" },
            { "gtq", "Quetzal ya Guatemala" },
            { "gyd", "Dola ya Guyana" },
            { "hkd", "Dola ya Hong Kong" },
            { "hnl", "Lempira ya Hondurasi" },
            { "hrk", "Kuna ya Croatia" },
            { "htg", "Gourde ya Haiti" },
            { "huf", "Forint ya Hungaria" },
            { "idr", "Rupiah ya Indonesia" },
            { "ils", "Shekeli Mpya ya Israel" },
            { "inr", "Rupia ya India" },
            { "iqd", "Dinar ya Iraq" },
            { "irr", "Rial ya Iran" },
            { "isk", "Krona ya Aisilandi" },
            { "jmd", "Dola ya Jamaica" },
            { "jod", "Dinar ya Jordan" },
            { "jpy", "Yen ya Ujapani" },
            { "kes", "Shilingi ya Kenya" },
            { "kgs", "Som ya Kyrgystan" },
            { "khr", "Riel ya Cambodia" },
            { "kmf", "Faranga ya Comoros" },
            { "kpw", "Won ya Korea Kaskazini" },
            { "krw", "Won ya Korea Kusini" },
            { "kwd", "Dinar ya Kuwait" },
            { "kyd", "Dola ya Visiwa vya Cayman" },
            { "kzt", "Tenge ya Kazakhstan" },
            { "lak", "Kip ya Laosi" },
            { "lbp", "Pauni ya Lebanon" },
            { "lkr", "Rupia ya Sri Lanka" },
            { "lrd", "Dola ya Liberia" },
            { "lsl", "Loti ya Lesoto" },
            { "ltl", "Litas ya Lithuania" },
            { "lvl", "Lats ya Lativia" },
            { "lyd", "Dinari ya Libya" },
            { "mad", "Dirham ya Morocco" },
            { "mdl", "Leu ya Moldova" },
            { "mga", "Ariari ya Madagascar" },
            { "mkd", "Denar ya Macedonia" },
            { "mmk", "Kyat ya Myanmar" },
            { "mnt", "Tugrik ya Mongolia" },
            { "mop", "Pataca ya Macau" },
            { "mro", "Ouguiya ya Mauritania (1973\u20132017)" },
            { "mru", "Ouguiya ya Mauritania" },
            { "mur", "Rupia ya Mauritius" },
            { "mvr", "Rufiyaa ya Maldives" },
            { "mwk", "Kwacha ya Malawi" },
            { "mxn", "Peso ya Mexico" },
            { "myr", "Ringgit ya Malaysia" },
            { "mzm", "Metikali ya Msumbiji (1980\u20132006)" },
            { "mzn", "Metikali ya Msumbiji" },
            { "nad", "Dola ya Namibia" },
            { "ngn", "Naira ya Nigeria" },
            { "nio", "Cordoba ya Nicaragua" },
            { "nok", "Krone ya Norway" },
            { "npr", "Rupia ya Nepal" },
            { "nzd", "Dola ya New Zealand" },
            { "omr", "Rial ya Omani" },
            { "pab", "Balboa ya Panama" },
            { "pen", "Sol ya Peru" },
            { "pgk", "Kina ya Papua New Guinea" },
            { "php", "Peso ya Ufilipino" },
            { "pkr", "Rupia ya Pakistan" },
            { "pln", "Zloty ya Poland" },
            { "pyg", "Guarani ya Paraguay" },
            { "qar", "Rial ya Qatar" },
            { "ron", "Leu ya Romania" },
            { "rsd", "Dinar ya Serbia" },
            { "rub", "Ruble ya Urusi" },
            { "rwf", "Faranga ya Rwanda" },
            { "sar", "Riyal ya Saudia" },
            { "sbd", "Dola ya Visiwa vya Solomon" },
            { "scr", "Rupia ya Ushelisheli" },
            { "sdg", "Pauni ya Sudan" },
            { "sdp", "Pauni ya Sudani (1957\u20131998)" },
            { "sek", "Krona ya Uswidi" },
            { "sgd", "Dola ya Singapore" },
            { "shp", "Pauni ya St. Helena" },
            { "sll", "Leone" },
            { "sos", "Shilingi ya Somalia" },
            { "srd", "Dola ya Suriname" },
            { "ssp", "Pauni ya Sudan Kusini" },
            { "std", "Dobra ya Sao Tome na Principe (1977\u20132017)" },
            { "stn", "Dobra ya Sao Tome na Principe" },
            { "syp", "Pauni ya Syria" },
            { "szl", "Lilangeni" },
            { "thb", "Baht ya Tailandi" },
            { "tjs", "Somoni ya Tajikistan" },
            { "tmt", "Manat ya Turkmenistan" },
            { "tnd", "Dinari ya Tunisia" },
            { "top", "Pa\u02bbanga ya Tonga" },
            { "try", "Lira ya Uturuki" },
            { "ttd", "Dola ya Trinidad na Tobago" },
            { "twd", "Dola ya Taiwan" },
            { "tzs", "Shilingi ya Tanzania" },
            { "uah", "Hryvnia ya Ukraine" },
            { "ugx", "Shilingi ya Uganda" },
            { "usd", "Dola ya Marekani" },
            { "uyu", "Peso ya Uruguay" },
            { "uzs", "Som ya Uzbekistan" },
            { "vef", "Bolivar ya Venezuela (2008\u20132018)" },
            { "ves", "Bolivar ya Venezuela" },
            { "vnd", "Dong ya Vietnam" },
            { "vuv", "Vatu ya Vanuatu" },
            { "wst", "Tala ya Samoa" },
            { "xaf", "Faranga ya Afrika ya Kati CFA" },
            { "xcd", "Dola ya Caribbean Mashariki" },
            { "xof", "Faranga ya Afrika Magharibi CFA" },
            { "xpf", "Faranga ya CFP" },
            { "xxx", "Sarafu isiyojulikana" },
            { "yer", "Rial ya Yemen" },
            { "zar", "Randi ya Afrika Kusini" },
            { "zmk", "Kwacha ya Zambia (1968\u20132012)" },
            { "zmw", "Kwacha ya Zambia" },
            { "zwd", "Dola ya Zimbabwe" },
        };
        return data;
    }
}
